Index: trunk/ippTools/src/detselect.c
===================================================================
--- trunk/ippTools/src/detselect.c	(revision 10161)
+++ trunk/ippTools/src/detselect.c	(revision 11075)
@@ -90,5 +90,5 @@
         // "   detRun.state,"
         // "   detRunSummary.accept,"
-        // "   rawDetrendExp.camera"
+        // "   rawExp.camera"
         " FROM detRun"
         " JOIN detRunSummary "
@@ -97,8 +97,8 @@
         "   ON detRunSummary.det_id = detInputExp.det_id"
         "   AND detRunSummary.iteration = detInputExp.iteration"
-        " JOIN rawDetrendExp"
-        "   ON detInputExp.exp_tag = rawDetrendExp.exp_tag"
+        " JOIN rawExp"
+        "   ON detInputExp.exp_tag = rawExp.exp_tag"
         " JOIN rawImfile"
-        "   ON rawDetrendExp.exp_tag = rawImfile.exp_tag"
+        "   ON rawExp.exp_tag = rawImfile.exp_tag"
         " WHERE"
         "   detRun.state = 'stop'"
@@ -106,5 +106,5 @@
         // XXX the following entry is needed to exclude db mismatched
         // XXX these are caused by an error upstream and should be fixed
 //        "   AND detRun.det_type = rawDetrendExp.object"
     );
 # endif
@@ -106,5 +106,5 @@
         // XXX the following entry is needed to exclude db mismatched
         // XXX these are caused by an error upstream and should be fixed
-//        "   AND detRun.det_type = rawDetrendExp.object"
+//        "   AND detRun.det_type = rawExp.object"
     );
 # endif
